"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpenAiIntentMatcher = void 0;
// Import the OpenAI class from the 'openai' package.
const openai_1 = require("openai");
// Import helper functions for matching tools and parsing parameters based on intent.
const get_tool_for_intent_1 = require("./get-tool-for-intent");
const parse_tool_parameters_1 = require("./parse-tool-parameters");
class OpenAiIntentMatcher {
    static name = 'OpenAI Intent Matcher';
    static requiredCredentialNames = ['openAiApiKey'];
    openai;
    model;
    constructor(apiKey, model = 'gpt-4o-mini') {
        this.openai = new openai_1.OpenAI({ apiKey: apiKey });
        this.model = model;
    }
    async analyzeIntentAndMatchTool(intent, registeredTools) {
        if (!this.openai) {
            throw new Error('OpenAI client not initialized. Please set credentials first.');
        }
        const { analysis, matchedTool } = await (0, get_tool_for_intent_1.getToolForIntent)(this.openai, this.model, intent, registeredTools);
        // If a tool is matched, parse the parameters from the intent using `parseToolParametersFromIntent`.
        const params = matchedTool
            ? await (0, parse_tool_parameters_1.parseToolParametersFromIntent)(this.openai, this.model, intent, matchedTool)
            : { foundParams: {}, missingParams: [] }; // If no tool is matched, return empty parameters.
        // Return the analysis, matched tool, and parameters.
        return { analysis, matchedTool, params };
    }
}
exports.OpenAiIntentMatcher = OpenAiIntentMatcher;
